summaryrefslogtreecommitdiff
path: root/main/openvpn/src/openvpn/push.c
diff options
context:
space:
mode:
Diffstat (limited to 'main/openvpn/src/openvpn/push.c')
-rw-r--r--main/openvpn/src/openvpn/push.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/main/openvpn/src/openvpn/push.c b/main/openvpn/src/openvpn/push.c
index af351763..c7844499 100644
--- a/main/openvpn/src/openvpn/push.c
+++ b/main/openvpn/src/openvpn/push.c
@@ -303,7 +303,7 @@ send_push_reply (struct context *c)
if (multi_push)
buf_printf (&buf, ",push-continuation 1");
/* Send session-id if client supports it */
if (c->c2.tls_multi->peer_info)
{
const char* proto_str = strstr(c->c2.tls_multi->peer_info, "IV_PROTO=");
@@ -312,7 +312,7 @@ send_push_reply (struct context *c)
int proto = 0;
int r = sscanf(proto_str, "IV_PROTO=%d", &proto);
if ((r == 1) && (proto >= 2))
- buf_printf(&buf, ",session-id %d", c->c2.tls_multi->vpn_session_id);
+ buf_printf(&buf, ",peer-id %d", c->c2.tls_multi->peer_id);
}
}
@@ -303,7 +303,7 @@ send_push_reply (struct context *c)
if (multi_push)
buf_printf (&buf, ",push-continuation 1");
- /* Send session-id if client supports it */
+ /* Send peer-id if client supports it */
if (c->c2.tls_multi->peer_info)
{